@@ -446,7 +446,7 @@ void OgreHeightmap::Init()
     this->descriptor.SetName(this->Name());
 
   // Add paths
-  for (auto i = 0u; i < this->descriptor.TextureCount(); ++i)
+  for (uint64_t i = 0u; i < this->descriptor.TextureCount(); ++i)
   {
     auto texture = this->descriptor.TextureByIndex(i);
     OgreRenderEngine::Instance()->AddResourcePath(texture->Diffuse());
