@@ -821,19 +821,6 @@ void OgreMaterial::SetDepthMaterial(const double _far,
   // Get shader parameters path
   const char *env = std::getenv("GZ_RENDERING_RESOURCE_PATH");
 
-  // TODO(CH3): Deprecated. Remove on tock.
-  if (!env)
-  {
-    env = std::getenv("IGN_RENDERING_RESOURCE_PATH");
-
-    if (env)
-    {
-      gzwarn << "Using deprecated environment variable "
-             << "[IGN_RENDERING_RESOURCE_PATH]. Please use "
-             << "[GZ_RENDERING_RESOURCE_PATH] instead." << std::endl;
-    }
-  }
-
   std::string resourcePath = (env) ? std::string(env) :
       gz::rendering::getResourcePath();
 
