@@ -202,10 +202,10 @@ void Ogre2RenderEngine::Destroy()
   {
     // Clean up any textures that may still be in flight.
     Ogre::TextureGpuManager *mgr =
-    this->ogreRoot->getRenderSystem()->getTextureGpuManager();
+        this->ogreRoot->getRenderSystem()->getTextureGpuManager();
 
     auto entries = mgr->getEntries();
-    for (auto& [name, entry] : entries)
+    for (const auto& [name, entry] : entries)
     {
       if (entry.resourceGroup == "General" && !entry.destroyRequested)
         mgr->destroyTexture(entry.texture);
@@ -768,10 +768,6 @@ void Ogre2RenderEngine::LoadPlugins()
 //////////////////////////////////////////////////
 void Ogre2RenderEngine::CreateRenderSystem()
 {
-  Ogre::RenderSystem *renderSys;
-  const Ogre::RenderSystemList *rsList;
-
-  rsList = &(this->ogreRoot->getAvailableRenderers());
   std::string targetRenderSysName("OpenGL 3+ Rendering Subsystem");
   if (this->dataPtr->graphicsAPI == GraphicsAPI::VULKAN)
   {
@@ -782,27 +778,12 @@ void Ogre2RenderEngine::CreateRenderSystem()
     targetRenderSysName = "Metal Rendering Subsystem";
   }
 
-  int c = 0;
-
-  renderSys = nullptr;
-
+  Ogre::RenderSystem *renderSys = nullptr;
+  for (auto *render : this->ogreRoot->getAvailableRenderers())
   {
-    bool bContinue = false;
-    do
-    {
-      if (c == static_cast<int>(rsList->size()))
-        break;
-
-      renderSys = rsList->at(c);
-      c++;
-
-      // cpplint has a false positive when extending a while call to multiple
-      // lines (it thinks the while loop is empty), so we must put the whole
-      // while statement on one line and add NOLINT at the end so that cpplint
-      // doesn't complain about the line being too long
-      bContinue =
-        renderSys && renderSys->getName().compare(targetRenderSysName) != 0;
-    } while (bContinue);
+    renderSys = render;
+    if (renderSys && renderSys->getName() == targetRenderSysName)
+      break;
   }
 
   if (renderSys == nullptr)
