@@ -195,9 +195,9 @@ math::Color Ogre2Scene::AmbientLight() const
 }
 
 //////////////////////////////////////////////////
-void Ogre2Scene::ClearMaterialsCache(const std::string &_name)
+void Ogre2Scene::ClearMaterialsCache(const std::string &)
 {
-  this->meshFactory->ClearMaterialsCache(_name);
+  // no-op
 }
 
 //////////////////////////////////////////////////
