@@ -188,7 +188,7 @@ std::vector<std::string> RenderEngineManager::LoadedEngines() const
 {
   std::lock_guard<std::recursive_mutex> lock(this->dataPtr->enginesMutex);
   std::vector<std::string> engines;
-  for (auto [name, engine] :  // NOLINT(whitespace/braces)
+  for (const auto &[name, engine] :  // NOLINT(whitespace/braces)
       this->dataPtr->engines)
   {
     std::string n = name;
@@ -560,7 +560,7 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
     error << "Found no render engine plugins in ["
           << _filename << "], available interfaces are:"
           << std::endl;
-    for (auto pluginName : pluginNames)
+    for (const auto &pluginName : pluginNames)
     {
       error << "- " << pluginName << std::endl;
     }
@@ -575,7 +575,7 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
     warn << "Found multiple render engine plugins in ["
           << _filename << "]:"
           << std::endl;
-    for (auto pluginName : engineNames)
+    for (const auto &pluginName : engineNames)
     {
       warn << "- " << pluginName << std::endl;
     }
