@@ -139,17 +139,17 @@ TEST_F(MeshTest, MeshSkeleton)
 
   int g_animIdx = 1;
   auto * skelAnim = skel->Animation(g_animIdx);
-  for (double i = 0; i < 10; i+=0.01)
+  for (double i = 0; i < 10.0; i+=0.01)
   {
-    std::map<std::string, math::Matrix4d> animFrames;
-    animFrames = skelAnim->PoseAt(i, true);
+    std::map<std::string, math::Matrix4d> animFrames =
+            skelAnim->PoseAt(i, true);
 
     std::map<std::string, math::Matrix4d> skinFrames;
 
-    for (auto pair : animFrames)
+    for (const auto &pair : animFrames)
     {
-      std::string animName = pair.first;
-      auto animTf = pair.second;
+      const auto &animName = pair.first;
+      const auto &animTf = pair.second;
 
       std::string skinName = skel->NodeNameAnimToSkin(g_animIdx, animName);
       math::Matrix4d skinTf =
