@@ -32,7 +32,7 @@
 
 #include <gz/utils/ExtraTestMacros.hh>
 
-#define DOUBLE_TOL 1e-6
+constexpr double DOUBLE_TOL = 1e-6;
 unsigned int g_pointCloudCounter = 0;
 
 /////////////////////////////////////////////////
@@ -41,9 +41,12 @@ void OnNewRgbPointCloud(float *_scanDest, const float *_scan,
                   unsigned int _channels,
                   const std::string &/*_format*/)
 {
-  float f;
-  int size =  _width * _height * _channels;
-  memcpy(_scanDest, _scan, size * sizeof(f));
+  EXPECT_EQ(10u, _width);
+  EXPECT_EQ(10u, _height);
+  EXPECT_EQ(4u, _channels);
+
+  const auto size = _width * _height * _channels;
+  memcpy(_scanDest, _scan, size * sizeof(float));
   g_pointCloudCounter++;
 }
 using namespace gz;
