@@ -33,8 +33,7 @@
 
 #include <gz/utils/ExtraTestMacros.hh>
 
-#define DEPTH_TOL 1e-4
-#define DOUBLE_TOL 1e-6
+constexpr double DOUBLE_TOL = 1e-6;
 
 unsigned int g_thermalCounter = 0;
 
@@ -49,9 +48,8 @@ void OnNewThermalFrame(uint16_t *_scanDest, const uint16_t *_scan,
   EXPECT_EQ(50u, _height);
   EXPECT_EQ(1u, _channels);
 
-  uint16_t u;
-  int size =  _width * _height * _channels;
-  memcpy(_scanDest, _scan, size * sizeof(u));
+  const auto size =  _width * _height * _channels;
+  memcpy(_scanDest, _scan, size * sizeof(uint16_t));
 }
 
 //////////////////////////////////////////////////
@@ -820,3 +818,213 @@ TEST_F(ThermalCameraTest, ThermalCameraMaxTemperatureIsClamped)
 
   engine->DestroyScene(scene);
 }
+
+//////////////////////////////////////////////////
+TEST_F(ThermalCameraTest, ThermalCameraMinTemperatureUpdate)
+{
+  // Updating the min temperature currently only works with Ogre2
+  CHECK_SUPPORTED_ENGINE("ogre2");
+
+  const unsigned int imgWidth = 50;
+  const unsigned int imgHeight = 50;
+
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
+
+  {
+    // Create thermal camera
+    auto thermalCamera = scene->CreateThermalCamera("ThermalCamera");
+    ASSERT_NE(thermalCamera, nullptr);
+
+    // Configure thermal camera
+    thermalCamera->SetImageWidth(imgWidth);
+    EXPECT_EQ(thermalCamera->ImageWidth(), imgWidth);
+    thermalCamera->SetImageHeight(imgHeight);
+    EXPECT_EQ(thermalCamera->ImageHeight(), imgHeight);
+
+    scene->RootVisual()->AddChild(thermalCamera);
+
+    // Set a callback on the camera sensor to get a thermal camera frame
+    std::vector<uint16_t> thermalData(imgHeight * imgWidth);
+    gz::common::ConnectionPtr connection =
+      thermalCamera->ConnectNewThermalFrame(
+          std::bind(&::OnNewThermalFrame, thermalData.data(),
+            std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
+            std::placeholders::_4, std::placeholders::_5));
+    EXPECT_NE(nullptr, connection);
+
+    const float linearResolution = 0.01f;
+    thermalCamera->SetLinearResolution(linearResolution);
+    EXPECT_FLOAT_EQ(linearResolution, thermalCamera->LinearResolution());
+
+    // set a minimum temperature and a smaller ambient temperature
+    const float minTemp = 100.0f;
+    const float ambientTemp = 50.0f;
+    thermalCamera->SetMinTemperature(minTemp);
+    EXPECT_FLOAT_EQ(minTemp, thermalCamera->MinTemperature());
+    thermalCamera->SetAmbientTemperature(ambientTemp);
+    EXPECT_FLOAT_EQ(ambientTemp, thermalCamera->AmbientTemperature());
+
+    // Update once to create image
+    thermalCamera->Update();
+
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * linearResolution;
+      EXPECT_NEAR(temp, minTemp, linearResolution);
+    }
+
+    // set new minimum temperature
+    const float newMinTemp = 150.0f;
+    thermalCamera->SetMinTemperature(newMinTemp);
+    thermalCamera->Update();
+
+    // check that new minimum temperature is applied
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * linearResolution;
+      EXPECT_NEAR(temp, newMinTemp, linearResolution);
+    }
+
+    // Clean up
+    connection.reset();
+  }
+
+  engine->DestroyScene(scene);
+}
+
+//////////////////////////////////////////////////
+TEST_F(ThermalCameraTest, ThermalCameraMaxTemperatureUpdate)
+{
+  // Updating the max temperature currently only works with Ogre2
+  CHECK_SUPPORTED_ENGINE("ogre2");
+
+  const unsigned int imgWidth = 50;
+  const unsigned int imgHeight = 50;
+
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
+
+  {
+    // Create thermal camera
+    auto thermalCamera = scene->CreateThermalCamera("ThermalCamera");
+    ASSERT_NE(thermalCamera, nullptr);
+
+    // Configure thermal camera
+    thermalCamera->SetImageWidth(imgWidth);
+    EXPECT_EQ(thermalCamera->ImageWidth(), imgWidth);
+    thermalCamera->SetImageHeight(imgHeight);
+    EXPECT_EQ(thermalCamera->ImageHeight(), imgHeight);
+
+    scene->RootVisual()->AddChild(thermalCamera);
+
+    // Set a callback on the camera sensor to get a thermal camera frame
+    std::vector<uint16_t> thermalData(imgHeight * imgWidth);
+    gz::common::ConnectionPtr connection =
+      thermalCamera->ConnectNewThermalFrame(
+          std::bind(&::OnNewThermalFrame, thermalData.data(),
+            std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
+            std::placeholders::_4, std::placeholders::_5));
+    EXPECT_NE(nullptr, connection);
+
+    const float linearResolution = 0.01f;
+    thermalCamera->SetLinearResolution(linearResolution);
+    EXPECT_FLOAT_EQ(linearResolution, thermalCamera->LinearResolution());
+
+    // set a maximum temperature and a greater ambient temperature
+    const float maxTemp = 500.0f;
+    const float ambientTemp = 550.0f;
+    thermalCamera->SetMaxTemperature(maxTemp);
+    EXPECT_FLOAT_EQ(maxTemp, thermalCamera->MaxTemperature());
+    thermalCamera->SetAmbientTemperature(ambientTemp);
+    EXPECT_FLOAT_EQ(ambientTemp, thermalCamera->AmbientTemperature());
+
+    // Update once to create image
+    thermalCamera->Update();
+
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * linearResolution;
+      EXPECT_NEAR(temp, maxTemp, linearResolution);
+    }
+
+    // set new maximum temperature
+    const float newMaxTemp = 525.0f;
+    thermalCamera->SetMaxTemperature(newMaxTemp);
+    thermalCamera->Update();
+
+    // check that new maximum temperature is applied
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * linearResolution;
+      EXPECT_NEAR(temp, newMaxTemp, linearResolution);
+    }
+
+    // Clean up
+    connection.reset();
+  }
+
+  engine->DestroyScene(scene);
+}
+
+//////////////////////////////////////////////////
+TEST_F(ThermalCameraTest, ThermalCameraResolutionUpdate)
+{
+  // Updating the resolution currently only works with Ogre2
+  CHECK_SUPPORTED_ENGINE("ogre2");
+
+  const unsigned int imgWidth = 50;
+  const unsigned int imgHeight = 50;
+
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
+
+  {
+    // Create thermal camera
+    auto thermalCamera = scene->CreateThermalCamera("ThermalCamera");
+    ASSERT_NE(thermalCamera, nullptr);
+
+    // Configure thermal camera
+    thermalCamera->SetImageWidth(imgWidth);
+    EXPECT_EQ(thermalCamera->ImageWidth(), imgWidth);
+    thermalCamera->SetImageHeight(imgHeight);
+    EXPECT_EQ(thermalCamera->ImageHeight(), imgHeight);
+
+    scene->RootVisual()->AddChild(thermalCamera);
+
+    // Set a callback on the camera sensor to get a thermal camera frame
+    std::vector<uint16_t> thermalData(imgHeight * imgWidth);
+    gz::common::ConnectionPtr connection =
+      thermalCamera->ConnectNewThermalFrame(
+          std::bind(&::OnNewThermalFrame, thermalData.data(),
+            std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
+            std::placeholders::_4, std::placeholders::_5));
+    EXPECT_NE(nullptr, connection);
+
+    const float ambientTemp = 300.0f;
+    thermalCamera->SetAmbientTemperature(ambientTemp);
+    EXPECT_FLOAT_EQ(ambientTemp, thermalCamera->AmbientTemperature());
+
+    const float linearResolution = 0.01f;
+    thermalCamera->SetLinearResolution(linearResolution);
+    EXPECT_FLOAT_EQ(linearResolution, thermalCamera->LinearResolution());
+
+    // Update once to create image
+    thermalCamera->Update();
+
+    // check result with initial resolution
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * linearResolution;
+      EXPECT_NEAR(temp, ambientTemp, linearResolution);
+    }
+
+    // set new resolution
+    const float newLinearResolution = 0.02f;
+    thermalCamera->SetLinearResolution(newLinearResolution);
+    thermalCamera->Update();
+
+    // check that camera has applied the new resolution
+    for (const uint16_t value : thermalData) {
+      const float temp = static_cast<float>(value) * newLinearResolution;
+      EXPECT_NEAR(temp, ambientTemp, newLinearResolution);
+    }
+
+    // Clean up
+    connection.reset();
+  }
+
+  engine->DestroyScene(scene);
+}
