@@ -55,7 +55,11 @@ void OnNewWideAngleFrame(const unsigned char *_data,
                     unsigned int _channels,
                     const std::string &_format)
 {
-  g_mutex.lock();
+  EXPECT_EQ(320u, _width);
+  EXPECT_EQ(240u, _height);
+  EXPECT_EQ(3u, _channels);
+
+  std::lock_guard<std::mutex> lock(g_mutex);
   auto bufferSize = _width * _height * _channels;
 
   if (!g_buffer)
@@ -67,7 +71,6 @@ void OnNewWideAngleFrame(const unsigned char *_data,
   EXPECT_EQ("R8G8B8", _format);
 
   g_counter++;
-  g_mutex.unlock();
 }
 
 //////////////////////////////////////////////////
@@ -77,7 +80,11 @@ void OnNewWideAngleFrameMono(const unsigned char *_data,
                     unsigned int _channels,
                     const std::string &_format)
 {
-  g_mutex.lock();
+  EXPECT_EQ(20u, _width);
+  EXPECT_EQ(20u, _height);
+  EXPECT_EQ(1u, _channels);
+
+  std::lock_guard<std::mutex> lock(g_mutex);
 
   unsigned int bytesPerChannel = 0u;
   unsigned int bufferSize = 0u;
@@ -102,7 +109,6 @@ void OnNewWideAngleFrameMono(const unsigned char *_data,
   ASSERT_NE(0u, bufferSize);
 
   g_counter++;
-  g_mutex.unlock();
 }
 
 //////////////////////////////////////////////////
